# insituTEM

Tools for preprocessing in situ TEM movies.

Author: Meng Li (mona.mengli@gmail.com; mli4@bnl.gov)

## Installation
```bash
pip install insitutem-toolbox
```
## Module descriptions


### `insitu_IO`

in-situ TEM Toolbox - Input Output

Assembles of functions related to movie input output


### `insitu_Preprocess`

in-situ TEM Toolbox - PreProcess

Assembles of functions related to movie preprocess 


### `insitu_alignment`

in-situ TEM Toolbox - Movie alignment 

Assembles of functions related to movie alignment



### `insitu_DENS`

in-situ TEM Toolbox - DENS holder data process

Assembles of functions related to process raw data by DENS holders



### `insitu_DP`

in-situ TEM Toolbox - Image Data process 

Assembles of functions related to movie data analysis such as plots



### `insitu_Diff`

in-situ TEM Toolbox - Diffraction pattern analysis

Assembles of functions related to process FFT and diffraction patterns



### `insitu_EMraw`

in-situ TEM Toolbox - TEM raw data conversion

Assembles of functions related to read and process raw dm4, dm3 or FEI TIA or Ceta datas.
